==> softhsm2_2.0.0.orig.tar.gz: softhsm-2.0.0/src/lib/test/RandomTests.h <==
/*
 * Copyright (c) 2010 .SE (The Internet Infrastructure Foundation)
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
 * IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
 * IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/*****************************************************************************
 RandomTests.h

 Contains test cases to C_SeedRandom and C_GenerateRandom
 *****************************************************************************/

#ifndef _SOFTHSM_V2_RANDOMTESTS_H
#define _SOFTHSM_V2_RANDOMTESTS_H

#include <cppunit/extensions/HelperMacros.h>
#include "cryptoki.h"

class RandomTests : public CppUnit::TestFixture
{
	CPPUNIT_TEST_SUITE(RandomTests);
	CPPUNIT_TEST(testSeedRandom);
	CPPUNIT_TEST(testGenerateRandom);
	CPPUNIT_TEST_SUITE_END();

public:
	void testSeedRandom();
	void testGenerateRandom();

	void setUp();
	void tearDown();
};

#endif // !_SOFTHSM_V2_RANDOMTESTS_H

==> softhsm2_2.6.1.orig.tar.gz: softhsm2-2.6.1/src/lib/test/RandomTests.h <==
/*
 * Copyright (c) 2010 .SE (The Internet Infrastructure Foundation)
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
 * IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
 * IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/*****************************************************************************
 RandomTests.h

 Contains test cases to C_SeedRandom and C_GenerateRandom
 *****************************************************************************/

#ifndef _SOFTHSM_V2_RANDOMTESTS_H
#define _SOFTHSM_V2_RANDOMTESTS_H

#include "TestsNoPINInitBase.h"
#include <cppunit/extensions/HelperMacros.h>

class RandomTests : public TestsNoPINInitBase
{
	CPPUNIT_TEST_SUITE(RandomTests);
	CPPUNIT_TEST(testSeedRandom);
	CPPUNIT_TEST(testGenerateRandom);
	CPPUNIT_TEST_SUITE_END();

public:
	void testSeedRandom();
	void testGenerateRandom();
};

#endif // !_SOFTHSM_V2_RANDOMTESTS_H
